@@ -4,17 +4,18 @@ import multiprocessing as mp
 
 import numpy as np
 import datetime
-
+import warnings
 import torch
 from torch import optim
 from torch.utils.data import DataLoader
 from torch.optim.lr_scheduler import ReduceLROnPlateau
-
 from contextualized_topic_models.networks.decoding_network import DecoderNetwork
 
 
+
 class CTM(object):
-    """Class to train the contextualized topic model.
+    """Class to train the contextualized topic model. This is the more general class that we are keeping to
+    avoid braking code, user should use the two subclasses ZeroShotTM and CombinedTm to do topic modeling.
 
         :param input_size: int, dimension of input
         :param bert_input_size: int, dimension of input that comes from BERT embeddings
@@ -34,10 +35,15 @@ class CTM(object):
         :param num_data_loader_workers: int, number of data loader workers (default cpu_count). set it to 0 if you are using Windows
     """
 
-    def __init__(self, input_size, bert_input_size, inference_type, n_components=10, model_type='prodLDA',
+    def __init__(self, input_size, bert_input_size, inference_type="combined", n_components=10, model_type='prodLDA',
                  hidden_sizes=(100, 100), activation='softplus', dropout=0.2,
                  learn_priors=True, batch_size=64, lr=2e-3, momentum=0.99,
                  solver='adam', num_epochs=100, reduce_on_plateau=False, num_data_loader_workers=mp.cpu_count()):
+        warnings.simplefilter('always', DeprecationWarning)
+
+        if self.__class__.__name__ == "CTM":
+
+            warnings.warn("Direct call to CTM is deprecated and will be removed in version 2, use CombinedTM or ZeroShotTM", DeprecationWarning)
 
         assert isinstance(input_size, int) and input_size > 0,\
             "input_size must by type int > 0."
@@ -396,11 +402,30 @@ class CTM(object):
         :return: the predicted topics
         """
         predicted_topics = []
-        #thetas = np.zeros((len(dataset), self.n_components))
-
         thetas = self.get_thetas(dataset, n_samples)
 
         for idd in range(len(dataset)):
             predicted_topic = np.argmax(thetas[idd] / np.sum(thetas[idd]))
             predicted_topics.append(predicted_topic)
         return predicted_topics
+
+
+class ZeroShotTM(CTM):
+    """
+    ZeroShotTM, as described in https://arxiv.org/pdf/2004.07737v1.pdf
+    """
+
+    def __init__(self, **kwargs):
+        inference_type = "zeroshot"
+        super().__init__(inference_type=inference_type, **kwargs)
+
+
+class CombinedTM(CTM):
+    """
+    CombinedTM, as described in https://arxiv.org/pdf/2004.03974.pdf
+    """
+    def __init__(self, **kwargs):
+        inference_type = "combined"
+        super().__init__(inference_type=inference_type, **kwargs)
+
+
