@@ -2,13 +2,14 @@
 
 """Tests for `contextualized_topic_models` package."""
 
-from contextualized_topic_models.models.ctm import CTM
+from contextualized_topic_models.models.ctm import CTM, ZeroShotTM, CombinedTM
 from contextualized_topic_models.utils.data_preparation import bert_embeddings_from_file, bert_embeddings_from_list
 import numpy as np
 import pickle
 from contextualized_topic_models.utils.data_preparation import TextHandler
+from contextualized_topic_models.utils.data_preparation import QuickText
 from contextualized_topic_models.datasets.dataset import CTMDataset
-from contextualized_topic_models.utils.preprocessing import SimplePreprocessing
+from contextualized_topic_models.utils.preprocessing import WhiteSpacePreprocessing, SimplePreprocessing
 
 import os
 import pytest
@@ -63,11 +64,7 @@ def test_embeddings_from_scratch(data_dir):
                                              [1, 1, 1, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0],
                                              [0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 2]]))
 
-    train_bert = bert_embeddings_from_file(data_dir + 'sample_text_document', "distiluse-base-multilingual-cased")
-
-    assert len(train_bert) == len(handler.bow.todense())
-
-def test_training(data_dir):
+def test_training_all_classes_ctm(data_dir):
     handler = TextHandler(data_dir + "sample_text_document")
     handler.prepare()  # create vocabulary and training data
 
@@ -78,6 +75,7 @@ def test_training(data_dir):
 
     ctm = CTM(input_size=len(handler.vocab), bert_input_size=512, num_epochs=1, inference_type="combined",
               n_components=5)
+
     ctm.fit(training_dataset)  # run the model
     topics = ctm.get_topic_lists(2)
     assert len(topics) == 5
@@ -85,8 +83,23 @@ def test_training(data_dir):
     thetas = ctm.get_thetas(training_dataset)
     assert len(thetas) == len(train_bert)
 
+    ctm = ZeroShotTM(input_size=len(handler.vocab), bert_input_size=512, num_epochs=1,
+                     n_components=5)
+    ctm.fit(training_dataset)  # run the model
+    topics = ctm.get_topic_lists(2)
+    assert len(topics) == 5
 
-def test_training_from_lists(data_dir):
+    thetas = ctm.get_thetas(training_dataset)
+    assert len(thetas) == len(train_bert)
+
+    ctm = CombinedTM(input_size=len(handler.vocab), bert_input_size=512, num_epochs=1,
+                     n_components=5)
+    ctm.fit(training_dataset)  # run the model
+    topics = ctm.get_topic_lists(2)
+    assert len(topics) == 5
+
+    thetas = ctm.get_thetas(training_dataset)
+    assert len(thetas) == len(train_bert)
 
     with open(data_dir + 'sample_text_document') as filino:
         data = filino.readlines()
@@ -107,9 +120,26 @@ def test_training_from_lists(data_dir):
 
     assert len(thetas) == len(train_bert)
 
+    qt = QuickText("distiluse-base-multilingual-cased", text_for_bow=data, text_for_bert=data)
+
+    dataset = qt.load_dataset()
+
+    ctm = ZeroShotTM(input_size=len(qt.vocab), bert_input_size=512, num_epochs=1, n_components=5)
+    ctm.fit(dataset)  # run the model
+    topics = ctm.get_topic_lists(2)
+    assert len(topics) == 5
+
 
 def test_preprocessing(data_dir):
     docs = [line.strip() for line in open(data_dir + "gnews/GoogleNews.txt", 'r').readlines()]
+    sp = WhiteSpacePreprocessing(docs, "english")
+    prep_corpus, unprepr_corpus, vocab = sp.preprocess()
+
+    assert len(prep_corpus) == len(unprepr_corpus)  # prep docs must have the same size as the unprep docs
+    assert len(prep_corpus) <= len(docs)  # preprocessed docs must be less than or equal the original docs
+
+    assert len(vocab) <= sp.vocabulary_size  # check vocabulary size
+
     sp = SimplePreprocessing(docs)
     prep_corpus, unprepr_corpus, vocab = sp.preprocess()
 
@@ -118,3 +148,4 @@ def test_preprocessing(data_dir):
 
     assert len(vocab) <= sp.vocabulary_size  # check vocabulary size
 
+
